@@ -3,5 +3,6 @@
 May  15 12:04:49 2019
 @author: Julien Piccini
 """
-__version__ = "0.2.2"
+from .__version__ import __version__
 from .launchpy import *
+from .configs import *
\ No newline at end of file
